==> framework-plugin-low-code-0.7.30.tgz: package/template/mp/page/index.js <==
import { observable } from 'mobx';
import { createPage } from '<%= subLevelPath %>../../common/weapp-page'
import { mpCompToWidget } from '<%= subLevelPath %>../../common/widget'
import { concatClassList, px2rpx } from '<%= subLevelPath %>../../common/style'
import { app } from '<%= subLevelPath %>../../app/weapps-api'
import { $page } from './api'
import { <%= pageName %> as handlers } from '../../app/handlers'
import lifecyle from '../../lowcode/<%= pageName %>/lifecycle'
import state from '../../lowcode/<%= pageName %>/state'
import computed from '../../lowcode/<%= pageName %>/computed'

const context = observable({});

const widgetProps = <%= stringifyObj(widgetProps, {depth: null}) %>
/** widget event listeners **/
const evtListeners = {<% Object.entries(eventHanlders).map(([handlerName, listeners])=>{%>
  <%= handlerName%>: [
    <%listeners.map(l=> { %>{
      key: '<%= l.key %>',
      handler: <% if (l.type === 'rematch') {%> handlers.<%= l.handler %> <%} else if (l.type == 'material') {%> function(...args) { return require('../../materials/<%= l.handlerModule %>/actions/<%= l.handler %>/index').default(...args) } <%} else {%> <%= l.handler %> <%} %>,
      data: <%= stringifyObj(l.data, {depth: null}) %>,
      boundData: {<% Object.entries(l.boundData).map(([prop, expr])=>{%>'<%= prop %>':(lists, forItems, event, $context) => {const $for = forItems; return (
        <%= expr === '' ? 'undefined': expr %>
      )},
        <%}) %>}
    },<%})%>
  ],<%})%>
}
const dataBinds = {<% Object.entries(dataBinds).map(([id, widgetBinds])=>{%>
  <%= id %>: { <% Object.entries(widgetBinds).map(([prop, expr]) => { %>
    <%= prop %>: function (lists, forItems, event, $context) {const $for = forItems; return (
      <%= expr === '' ? 'undefined': expr %>
    ); },<% }) %>
  },<%}) %>
}

const pageAttributes = <%= pageAttributes?JSON.stringify(pageAttributes):'{}' %>

$page.id = '<%= pageName %>'
$page.uuid = '<%= pageUUID %>'
$page.handler = handlers
createPage(lifecyle, widgetProps, state, computed, evtListeners, dataBinds, app, $page, context,pageAttributes)

==> framework-plugin-low-code-0.7.35.tgz: package/template/mp/page/index.js <==
import { observable } from 'mobx';
import { createPage } from '<%= subLevelPath %>../../common/weapp-page'
import { mpCompToWidget } from '<%= subLevelPath %>../../common/widget'
import { concatClassList, px2rpx } from '<%= subLevelPath %>../../common/style'
import { app } from '<%= subLevelPath %>../../app/weapps-api'
import { $page } from './api'
import { <%= pageName %> as handlers } from '../../app/handlers'
import lifecyle from '../../lowcode/<%= pageName %>/lifecycle'
import state from '../../lowcode/<%= pageName %>/state'
import computed from '../../lowcode/<%= pageName %>/computed'

const context = observable({});

const widgetProps = <%= stringifyObj(widgetProps, {depth: null}) %>
/** widget event listeners **/
const evtListeners = {<% Object.entries(eventHanlders).map(([handlerName, listeners])=>{%>
  <%= handlerName%>: [
    <%listeners.map(l=> { %>{
      key: '<%= l.key %>',
      handler: <% if (l.type === 'rematch') {%> handlers.<%= l.handler %> <%} else if (l.type == 'material') {%> function(...args) { return require('../../materials/<%= l.handlerModule %>/actions/<%= l.handler %>/index').default(...args) } <%} else {%> <%= l.handler %> <%} %>,
      data: <%= stringifyObj(l.data, {depth: null}) %>,
      boundData: {<% Object.entries(l.boundData).map(([prop, expr])=>{%>'<%= prop %>':(lists, forItems, event, $context) => {const $for = forItems; return (
        <%= expr === '' ? 'undefined': expr %>
      )},
        <%}) %>}
    },<%})%>
  ],<%})%>
}
const dataBinds = {<% Object.entries(dataBinds).map(([id, widgetBinds])=>{%>
  <%= id %>: { <% Object.entries(widgetBinds).map(([prop, expr]) => { %>
    '<%= prop %>': function (lists, forItems, event, $context) {const $for = forItems; return (
      <%= expr === '' ? 'undefined': expr %>
    ); },<% }) %>
  },<%}) %>
}

const pageAttributes = <%= pageAttributes?JSON.stringify(pageAttributes):'{}' %>

$page.id = '<%= pageName %>'
$page.uuid = '<%= pageUUID %>'
$page.handler = handlers
createPage(lifecyle, widgetProps, state, computed, evtListeners, dataBinds, app, $page, context,pageAttributes)
